pub struct QueueDeposit {
pub payer: Pubkey,
pub queue: Pubkey,
pub signer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for QueueDeposit.
Fields
payer: Pubkeyqueue: Pubkeysigner: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for QueueDepositwhere
Pubkey: BorshSerialize,
impl BorshSerialize for QueueDepositwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for QueueDeposit
impl ToAccountMetas for QueueDeposit
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for QueueDeposit
impl RefUnwindSafe for QueueDeposit
impl Send for QueueDeposit
impl Sync for QueueDeposit
impl Unpin for QueueDeposit
impl UnwindSafe for QueueDeposit