pub struct QueueResume {
pub authority: Pubkey,
pub queue: Pubkey,
}Expand description
Generated client accounts for QueueResume.
Fields
queue: PubkeyTrait Implementations
Sourceimpl BorshSerialize for QueueResumewhere
Pubkey: BorshSerialize,
impl BorshSerialize for QueueResumewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for QueueResume
impl ToAccountMetas for QueueResume
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for QueueResume
impl RefUnwindSafe for QueueResume
impl Send for QueueResume
impl Sync for QueueResume
impl Unpin for QueueResume
impl UnwindSafe for QueueResume