Struct clockwork_scheduler::accounts::QueueUpdate
source · [−]pub struct QueueUpdate {
pub authority: Pubkey,
pub queue: Pubkey,
}Expand description
Generated client accounts for QueueUpdate.
Fields
queue: PubkeyTrait Implementations
sourceimpl BorshSerialize for QueueUpdate where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for QueueUpdate where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for QueueUpdate
impl ToAccountMetas for QueueUpdate
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more