pub struct QueueWithdraw {
pub authority: Pubkey,
pub pay_to: Pubkey,
pub queue: Pubkey,
}Expand description
Generated client accounts for QueueWithdraw.
Fields
pay_to: Pubkeyqueue: PubkeyTrait Implementations
Sourceimpl BorshSerialize for QueueWithdrawwhere
Pubkey: BorshSerialize,
impl BorshSerialize for QueueWithdrawwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for QueueWithdraw
impl ToAccountMetas for QueueWithdraw
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for QueueWithdraw
impl RefUnwindSafe for QueueWithdraw
impl Send for QueueWithdraw
impl Sync for QueueWithdraw
impl Unpin for QueueWithdraw
impl UnwindSafe for QueueWithdraw