pub struct TaskClose {
pub authority: Pubkey,
pub close_to: Pubkey,
pub queue: Pubkey,
pub task: Pubkey,
}Expand description
Generated client accounts for TaskClose.
Fields
close_to: Pubkeyqueue: Pubkeytask: PubkeyTrait Implementations
Sourceimpl BorshSerialize for TaskClosewhere
Pubkey: BorshSerialize,
impl BorshSerialize for TaskClosewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for TaskClose
impl ToAccountMetas for TaskClose
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for TaskClose
impl RefUnwindSafe for TaskClose
impl Send for TaskClose
impl Sync for TaskClose
impl Unpin for TaskClose
impl UnwindSafe for TaskClose