Struct clockwork_scheduler::accounts::TaskNew
source · [−]pub struct TaskNew {
pub authority: Pubkey,
pub payer: Pubkey,
pub queue: Pubkey,
pub system_program: Pubkey,
pub task: Pubkey,
}Expand description
Generated client accounts for TaskNew.
Fields
payer: Pubkeyqueue: Pubkeysystem_program: Pubkeytask: PubkeyTrait Implementations
sourceimpl BorshSerialize for TaskNew where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for TaskNew where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for TaskNew
impl ToAccountMetas for TaskNew
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more