Struct clockwork_scheduler::accounts::TaskUpdate
source · [−]pub struct TaskUpdate {
pub authority: Pubkey,
pub queue: Pubkey,
pub task: Pubkey,
}Expand description
Generated client accounts for TaskUpdate.
Fields
queue: Pubkeytask: PubkeyTrait Implementations
sourceimpl BorshSerialize for TaskUpdate where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for TaskUpdate where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for TaskUpdate
impl ToAccountMetas for TaskUpdate
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more