Module instruction

Module instruction 

An Anchor generated module containing the program’s set of instructions, where each method handler in the #[program] mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when speciying instructions on a client.

Modules

state
Instruction struct definitions for #[state] methods.

Structs

AdminConfigUpdate
Instruction.
AdminFeeClaim
Instruction.
FeeClaim
Instruction.
Initialize
Instruction.
QueueClose
Instruction.
QueueDeposit
Instruction.
QueueNew
Instruction.
QueuePause
Instruction.
QueueProcess
Instruction.
QueueResume
Instruction.
QueueUpdate
Instruction.
QueueWithdraw
Instruction.
TaskClose
Instruction.
TaskExec
Instruction.
TaskNew
Instruction.
TaskUpdate
Instruction.