Struct clockwork_scheduler::instruction::QueueNew
source · [−]Expand description
Instruction.
Fields
balance: u64name: Stringschedule: StringTrait Implementations
sourceimpl BorshDeserialize for QueueNew where
u64: BorshDeserialize,
String: BorshDeserialize,
String: BorshDeserialize,
impl BorshDeserialize for QueueNew where
u64: BorshDeserialize,
String: BorshDeserialize,
String: BorshDeserialize,
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes. Updates the buffer to point at the remaining bytes. Read more
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.