Struct clockwork_scheduler::instruction::QueueResume
source · [−]pub struct QueueResume {
pub skip_forward: bool,
}Expand description
Instruction.
Fields
skip_forward: boolTrait Implementations
sourceimpl BorshDeserialize for QueueResume where
bool: BorshDeserialize,
impl BorshDeserialize for QueueResume where
bool: BorshDeserialize,
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes. Updates the buffer to point at the remaining bytes. Read more
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
sourceimpl BorshSerialize for QueueResume where
bool: BorshSerialize,
impl BorshSerialize for QueueResume where
bool: BorshSerialize,