Struct clockwork_scheduler::instruction::TaskNew
source · [−]pub struct TaskNew {
pub ixs: Vec<InstructionData>,
}Expand description
Instruction.
Fields
ixs: Vec<InstructionData>Trait Implementations
sourceimpl BorshDeserialize for TaskNew where
Vec<InstructionData>: BorshDeserialize,
impl BorshDeserialize for TaskNew where
Vec<InstructionData>: BorshDeserialize,
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes. Updates the buffer to point at the remaining bytes. Read more
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
sourceimpl BorshSerialize for TaskNew where
Vec<InstructionData>: BorshSerialize,
impl BorshSerialize for TaskNew where
Vec<InstructionData>: BorshSerialize,