Struct clockwork_scheduler::response::TaskResponse
source · [−]Fields
dynamic_accounts: Option<Vec<Pubkey>>Trait Implementations
sourceimpl BorshDeserialize for TaskResponse where
Option<Vec<Pubkey>>: BorshDeserialize,
impl BorshDeserialize for TaskResponse where
Option<Vec<Pubkey>>: BorshDeserialize,
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes. Updates the buffer to point at the remaining bytes. Read more
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
sourceimpl BorshSerialize for TaskResponse where
Option<Vec<Pubkey>>: BorshSerialize,
impl BorshSerialize for TaskResponse where
Option<Vec<Pubkey>>: BorshSerialize,
sourceimpl Clone for TaskResponse
impl Clone for TaskResponse
sourcefn clone(&self) -> TaskResponse
fn clone(&self) -> TaskResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for TaskResponse
impl Debug for TaskResponse