Enum clockwork_scheduler::state::QueueStatus
source · [−]pub enum QueueStatus {
Paused,
Pending,
Processing {
task_id: u64,
},
}Expand description
QueueStatus
Variants
Paused
Pending
Processing
Fields
task_id: u64Trait Implementations
sourceimpl BorshDeserialize for QueueStatus where
u64: BorshDeserialize,
impl BorshDeserialize for QueueStatus where
u64: BorshDeserialize,
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes. Updates the buffer to point at the remaining bytes. Read more
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
sourceimpl BorshSerialize for QueueStatus where
u64: BorshSerialize,
impl BorshSerialize for QueueStatus where
u64: BorshSerialize,
sourceimpl Clone for QueueStatus
impl Clone for QueueStatus
sourcefn clone(&self) -> QueueStatus
fn clone(&self) -> QueueStatus
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for QueueStatus
impl Debug for QueueStatus
sourceimpl PartialEq<QueueStatus> for QueueStatus
impl PartialEq<QueueStatus> for QueueStatus
sourcefn eq(&self, other: &QueueStatus) -> bool
fn eq(&self, other: &QueueStatus) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &QueueStatus) -> bool
fn ne(&self, other: &QueueStatus) -> bool
This method tests for !=.
impl Copy for QueueStatus
impl Eq for QueueStatus
impl StructuralEq for QueueStatus
impl StructuralPartialEq for QueueStatus