An Anchor generated module containing the program’s set of
instructions, where each method handler in the #[program] mod is
associated with a struct defining the input arguments to the
method. These should be used directly, when one wants to serialize
Anchor instruction data, for example, when speciying
instructions on a client.
Modules
- state
- Instruction struct definitions for
#[state]methods.
Structs
- Admin
Config Update - Instruction.
- Admin
FeeClaim - Instruction.
- FeeClaim
- Instruction.
- Initialize
- Instruction.
- Queue
Close - Instruction.
- Queue
Deposit - Instruction.
- Queue
New - Instruction.
- Queue
Pause - Instruction.
- Queue
Process - Instruction.
- Queue
Resume - Instruction.
- Queue
Update - Instruction.
- Queue
Withdraw - Instruction.
- Task
Close - Instruction.
- Task
Exec - Instruction.
- TaskNew
- Instruction.
- Task
Update - Instruction.